@@ -1,4 +1,4 @@
-use command_prelude::*;
+use crate::command_prelude::*;
 
 use cargo::core::{GitReference, Source, SourceId};
 use cargo::sources::GitSource;
@@ -21,7 +21,7 @@ pub fn cli() -> App {
         )
 }
 
-pub fn exec(config: &mut Config, args: &ArgMatches) -> CliResult {
+pub fn exec(config: &mut Config, args: &ArgMatches<'_>) -> CliResult {
     let url = args.value_of("url").unwrap().to_url()?;
     let reference = args.value_of("reference").unwrap();
 
