@@ -1,4 +1,4 @@
-use command_prelude::*;
+use crate::command_prelude::*;
 
 use cargo::ops;
 
@@ -6,14 +6,15 @@ pub fn cli() -> App {
     subcommand("init")
         .about("Create a new cargo package in an existing directory")
         .arg(Arg::with_name("path").default_value("."))
+        .arg(opt("registry", "Registry to use").value_name("REGISTRY"))
         .arg_new_opts()
 }
 
-pub fn exec(config: &mut Config, args: &ArgMatches) -> CliResult {
+pub fn exec(config: &mut Config, args: &ArgMatches<'_>) -> CliResult {
     let opts = args.new_options(config)?;
     ops::init(&opts, config)?;
     config
         .shell()
-        .status("Created", format!("{} project", opts.kind))?;
+        .status("Created", format!("{} package", opts.kind))?;
     Ok(())
 }
