@@ -1,4 +1,4 @@
-use command_prelude::*;
+use crate::command_prelude::*;
 
 use cargo::ops;
 
@@ -10,7 +10,7 @@ pub fn cli() -> App {
         .arg_new_opts()
 }
 
-pub fn exec(config: &mut Config, args: &ArgMatches) -> CliResult {
+pub fn exec(config: &mut Config, args: &ArgMatches<'_>) -> CliResult {
     let opts = args.new_options(config)?;
 
     ops::new(&opts, config)?;
@@ -20,8 +20,9 @@ pub fn exec(config: &mut Config, args: &ArgMatches) -> CliResult {
     } else {
         path
     };
-    config
-        .shell()
-        .status("Created", format!("{} `{}` package", opts.kind, package_name))?;
+    config.shell().status(
+        "Created",
+        format!("{} `{}` package", opts.kind, package_name),
+    )?;
     Ok(())
 }
