@@ -6,11 +6,11 @@ pub fn cli() -> App {
     subcommand("pkgid")
         .about("Print a fully qualified package specification")
         .arg(Arg::with_name("spec"))
-        .arg_package("Argument to get the package id specifier for")
+        .arg_package("Argument to get the package ID specifier for")
         .arg_manifest_path()
         .after_help(
             "\
-Given a <spec> argument, print out the fully qualified package id specifier.
+Given a <spec> argument, print out the fully qualified package ID specifier.
 This command will generate an error if <spec> is ambiguous as to which package
 it refers to in the dependency graph. If no <spec> is given, then the pkgid for
 the local package is printed.
