@@ -50,9 +50,9 @@ impl fmt::Display for Metadata {
 }
 
 pub struct CompilationFiles<'a, 'cfg: 'a> {
-    /// The target directory layout for the host (and target if it is the same as host)
+    /// The target directory layout for the host (and target if it is the same as host).
     pub(super) host: Layout,
-    /// The target directory layout for the target (if different from then host)
+    /// The target directory layout for the target (if different from then host).
     pub(super) target: Option<Layout>,
     /// Additional directory to include a copy of the outputs.
     export_dir: Option<PathBuf>,
@@ -70,7 +70,7 @@ pub struct OutputFile {
     /// Absolute path to the file that will be produced by the build process.
     pub path: PathBuf,
     /// If it should be linked into `target`, and what it should be called
-    /// (e.g. without metadata).
+    /// (e.g., without metadata).
     pub hardlink: Option<PathBuf>,
     /// If `--out-dir` is specified, the absolute path to the exported file.
     pub export_path: Option<PathBuf>,
@@ -79,7 +79,7 @@ pub struct OutputFile {
 }
 
 impl OutputFile {
-    /// Gets the hardlink if present. Otherwise returns the path.
+    /// Gets the hard link if present; otherwise, returns the path.
     pub fn bin_dst(&self) -> &PathBuf {
         match self.hardlink {
             Some(ref link_dst) => link_dst,
@@ -125,16 +125,16 @@ impl<'a, 'cfg: 'a> CompilationFiles<'a, 'cfg> {
         }
     }
 
-    /// Get the metadata for a target in a specific profile
-    /// We build to the path: "{filename}-{target_metadata}"
+    /// Gets the metadata for a target in a specific profile.
+    /// We build to the path `"{filename}-{target_metadata}"`.
     /// We use a linking step to link/copy to a predictable filename
     /// like `target/debug/libfoo.{a,so,rlib}` and such.
     pub fn metadata(&self, unit: &Unit<'a>) -> Option<Metadata> {
         self.metas[unit].clone()
     }
 
-    /// Get the short hash based only on the PackageId
-    /// Used for the metadata when target_metadata returns None
+    /// Gets the short hash based only on the `PackageId`.
+    /// Used for the metadata when `target_metadata` returns `None`.
     pub fn target_short_hash(&self, unit: &Unit<'_>) -> String {
         let hashable = unit.pkg.package_id().stable_hash(self.ws.root());
         util::short_hash(&hashable)
@@ -166,7 +166,7 @@ impl<'a, 'cfg: 'a> CompilationFiles<'a, 'cfg> {
         }
     }
 
-    /// Return the root of the build output tree
+    /// Returns the root of the build output tree.
     pub fn target_root(&self) -> &Path {
         self.host.dest()
     }
@@ -202,7 +202,7 @@ impl<'a, 'cfg: 'a> CompilationFiles<'a, 'cfg> {
         self.layout(unit.kind).build().join(dir).join("out")
     }
 
-    /// Returns the file stem for a given target/profile combo (with metadata)
+    /// Returns the file stem for a given target/profile combo (with metadata).
     pub fn file_stem(&self, unit: &Unit<'a>) -> String {
         match self.metas[unit] {
             Some(ref metadata) => format!("{}-{}", unit.target.crate_name(), metadata),
@@ -220,7 +220,7 @@ impl<'a, 'cfg: 'a> CompilationFiles<'a, 'cfg> {
             .map(Arc::clone)
     }
 
-    /// Returns the bin stem for a given target (without metadata)
+    /// Returns the bin stem for a given target (without metadata).
     fn bin_stem(&self, unit: &Unit<'_>) -> String {
         if unit.target.allows_underscores() {
             unit.target.name().to_string()
@@ -233,10 +233,10 @@ impl<'a, 'cfg: 'a> CompilationFiles<'a, 'cfg> {
     /// our target to be copied to. Eg, file_stem may be out_dir/deps/foo-abcdef
     /// and link_stem would be out_dir/foo
     /// This function returns it in two parts so the caller can add prefix/suffix
-    /// to filename separately
+    /// to filename separately.
     ///
-    /// Returns an Option because in some cases we don't want to link
-    /// (eg a dependent lib)
+    /// Returns an `Option` because in some cases we don't want to link
+    /// (eg a dependent lib).
     fn link_stem(&self, unit: &Unit<'a>) -> Option<(PathBuf, String)> {
         let out_dir = self.out_dir(unit);
         let bin_stem = self.bin_stem(unit);
@@ -246,7 +246,7 @@ impl<'a, 'cfg: 'a> CompilationFiles<'a, 'cfg> {
         // it was compiled into something like `example/` or `doc/` then
         // we don't want to link it up.
         if out_dir.ends_with("deps") {
-            // Don't lift up library dependencies
+            // Don't lift up library dependencies.
             if unit.target.is_bin() || self.roots.contains(unit) {
                 Some((
                     out_dir.parent().unwrap().to_owned(),
@@ -276,7 +276,7 @@ impl<'a, 'cfg: 'a> CompilationFiles<'a, 'cfg> {
         let out_dir = self.out_dir(unit);
         let file_stem = self.file_stem(unit);
         let link_stem = self.link_stem(unit);
-        let info = if unit.target.for_host() {
+        let info = if unit.kind == Kind::Host {
             &bcx.host_info
         } else {
             &bcx.target_info
@@ -333,14 +333,14 @@ impl<'a, 'cfg: 'a> CompilationFiles<'a, 'cfg> {
                                 });
                             }
                         }
-                        // not supported, don't worry about it
+                        // Not supported; don't worry about it.
                         None => {
                             unsupported.push(crate_type.to_string());
                         }
                     }
                     Ok(())
                 };
-                //info!("{:?}", unit);
+                // info!("{:?}", unit);
                 match *unit.target.kind() {
                     TargetKind::Bin
                     | TargetKind::CustomBuild
@@ -410,18 +410,18 @@ fn compute_metadata<'a, 'cfg>(
     cx: &Context<'a, 'cfg>,
     metas: &mut HashMap<Unit<'a>, Option<Metadata>>,
 ) -> Option<Metadata> {
-    // No metadata for dylibs because of a couple issues
-    // - OSX encodes the dylib name in the executable
-    // - Windows rustc multiple files of which we can't easily link all of them
+    // No metadata for dylibs because of a couple issues:
+    // - macOS encodes the dylib name in the executable,
+    // - Windows rustc multiple files of which we can't easily link all of them.
     //
-    // No metadata for bin because of an issue
-    // - wasm32 rustc/emcc encodes the .wasm name in the .js (rust-lang/cargo#4535)
+    // No metadata for bin because of an issue:
+    // - wasm32 rustc/emcc encodes the `.wasm` name in the `.js` (rust-lang/cargo#4535).
     //
-    // Two exceptions
-    // 1) Upstream dependencies (we aren't exporting + need to resolve name conflict)
-    // 2) __CARGO_DEFAULT_LIB_METADATA env var
+    // Two exceptions:
+    // 1) Upstream dependencies (we aren't exporting + need to resolve name conflict),
+    // 2) `__CARGO_DEFAULT_LIB_METADATA` env var.
     //
-    // Note, though, that the compiler's build system at least wants
+    // Note, however, that the compiler's build system at least wants
     // path dependencies (eg libstd) to have hashes in filenames. To account for
     // that we have an extra hack here which reads the
     // `__CARGO_DEFAULT_LIB_METADATA` environment variable and creates a
@@ -454,14 +454,14 @@ fn compute_metadata<'a, 'cfg>(
     1.hash(&mut hasher);
 
     // Unique metadata per (name, source, version) triple. This'll allow us
-    // to pull crates from anywhere w/o worrying about conflicts
+    // to pull crates from anywhere without worrying about conflicts.
     unit.pkg
         .package_id()
         .stable_hash(bcx.ws.root())
         .hash(&mut hasher);
 
     // Add package properties which map to environment variables
-    // exposed by Cargo
+    // exposed by Cargo.
     let manifest_metadata = unit.pkg.manifest().metadata();
     manifest_metadata.authors.hash(&mut hasher);
     manifest_metadata.description.hash(&mut hasher);
@@ -473,7 +473,7 @@ fn compute_metadata<'a, 'cfg>(
         .features_sorted(unit.pkg.package_id())
         .hash(&mut hasher);
 
-    // Mix in the target-metadata of all the dependencies of this target
+    // Mix in the target-metadata of all the dependencies of this target.
     {
         let mut deps_metadata = cx
             .dep_targets(unit)
@@ -485,7 +485,7 @@ fn compute_metadata<'a, 'cfg>(
     }
 
     // Throw in the profile we're compiling with. This helps caching
-    // panic=abort and panic=unwind artifacts, additionally with various
+    // `panic=abort` and `panic=unwind` artifacts, additionally with various
     // settings like debuginfo and whatnot.
     unit.profile.hash(&mut hasher);
     unit.mode.hash(&mut hasher);
@@ -514,7 +514,7 @@ fn compute_metadata<'a, 'cfg>(
 
     bcx.rustc.verbose_version.hash(&mut hasher);
 
-    // Seed the contents of __CARGO_DEFAULT_LIB_METADATA to the hasher if present.
+    // Seed the contents of `__CARGO_DEFAULT_LIB_METADATA` to the hasher if present.
     // This should be the release channel, to get a different hash for each channel.
     if let Ok(ref channel) = __cargo_default_lib_metadata {
         channel.hash(&mut hasher);
