@@ -2,19 +2,19 @@ use std::collections::hash_map::HashMap;
 use std::fmt;
 
 use crate::core::{Dependency, Package, PackageId, Summary};
-use crate::util::CargoResult;
+use crate::core::package::PackageSet;
+use crate::util::{CargoResult, Config};
 
 mod source_id;
 
 pub use self::source_id::{GitReference, SourceId};
 
-/// A Source finds and downloads remote packages based on names and
-/// versions.
+/// Something that finds and downloads remote packages based on names and versions.
 pub trait Source {
-    /// Returns the `SourceId` corresponding to this source
+    /// Returns the `SourceId` corresponding to this source.
     fn source_id(&self) -> SourceId;
 
-    /// Returns the replaced `SourceId` corresponding to this source
+    /// Returns the replaced `SourceId` corresponding to this source.
     fn replaced_source_id(&self) -> SourceId {
         self.source_id()
     }
@@ -27,13 +27,13 @@ pub trait Source {
     /// the `precise` field in the source id listed.
     fn requires_precise(&self) -> bool;
 
-    /// Attempt to find the packages that match a dependency request.
+    /// Attempts to find the packages that match a dependency request.
     fn query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()>;
 
-    /// Attempt to find the packages that are close to a dependency request.
+    /// Attempts to find the packages that are close to a dependency request.
     /// Each source gets to define what `close` means for it.
-    /// path/git sources may return all dependencies that are at that uri.
-    /// where as an Index source may return dependencies that have the same canonicalization.
+    /// Path/Git sources may return all dependencies that are at that URI,
+    /// whereas an `Index` source may return dependencies that have the same canonicalization.
     fn fuzzy_query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()>;
 
     fn query_vec(&mut self, dep: &Dependency) -> CargoResult<Vec<Summary>> {
@@ -42,15 +42,23 @@ pub trait Source {
         Ok(ret)
     }
 
-    /// The update method performs any network operations required to
-    /// get the entire list of all names, versions and dependencies of
-    /// packages managed by the Source.
+    /// Performs any network operations required to get the entire list of all names,
+    /// versions and dependencies of packages managed by the `Source`.
     fn update(&mut self) -> CargoResult<()>;
 
-    /// The download method fetches the full package for each name and
-    /// version specified.
+    /// Fetches the full package for each name and version specified.
     fn download(&mut self, package: PackageId) -> CargoResult<MaybePackage>;
 
+    fn download_now(self: Box<Self>, package: PackageId, config: &Config) -> CargoResult<Package>
+    where
+        Self: std::marker::Sized,
+    {
+        let mut sources = SourceMap::new();
+        sources.insert(self);
+        let pkg_set = PackageSet::new(&[package], sources, config)?;
+        Ok(pkg_set.get_one(package)?.clone())
+    }
+
     fn finish_download(&mut self, package: PackageId, contents: Vec<u8>) -> CargoResult<Package>;
 
     /// Generates a unique string which represents the fingerprint of the
@@ -79,7 +87,7 @@ pub trait Source {
     /// resolver error messages currently.
     fn describe(&self) -> String;
 
-    /// Returns whether a source is being replaced by another here
+    /// Returns whether a source is being replaced by another here.
     fn is_replaced(&self) -> bool {
         false
     }
@@ -96,42 +104,42 @@ pub enum MaybePackage {
 }
 
 impl<'a, T: Source + ?Sized + 'a> Source for Box<T> {
-    /// Forwards to `Source::source_id`
+    /// Forwards to `Source::source_id`.
     fn source_id(&self) -> SourceId {
         (**self).source_id()
     }
 
-    /// Forwards to `Source::replaced_source_id`
+    /// Forwards to `Source::replaced_source_id`.
     fn replaced_source_id(&self) -> SourceId {
         (**self).replaced_source_id()
     }
 
-    /// Forwards to `Source::supports_checksums`
+    /// Forwards to `Source::supports_checksums`.
     fn supports_checksums(&self) -> bool {
         (**self).supports_checksums()
     }
 
-    /// Forwards to `Source::requires_precise`
+    /// Forwards to `Source::requires_precise`.
     fn requires_precise(&self) -> bool {
         (**self).requires_precise()
     }
 
-    /// Forwards to `Source::query`
+    /// Forwards to `Source::query`.
     fn query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()> {
         (**self).query(dep, f)
     }
 
-    /// Forwards to `Source::query`
+    /// Forwards to `Source::query`.
     fn fuzzy_query(&mut self, dep: &Dependency, f: &mut dyn FnMut(Summary)) -> CargoResult<()> {
         (**self).fuzzy_query(dep, f)
     }
 
-    /// Forwards to `Source::update`
+    /// Forwards to `Source::update`.
     fn update(&mut self) -> CargoResult<()> {
         (**self).update()
     }
 
-    /// Forwards to `Source::download`
+    /// Forwards to `Source::download`.
     fn download(&mut self, id: PackageId) -> CargoResult<MaybePackage> {
         (**self).download(id)
     }
@@ -140,12 +148,12 @@ impl<'a, T: Source + ?Sized + 'a> Source for Box<T> {
         (**self).finish_download(id, data)
     }
 
-    /// Forwards to `Source::fingerprint`
+    /// Forwards to `Source::fingerprint`.
     fn fingerprint(&self, pkg: &Package) -> CargoResult<String> {
         (**self).fingerprint(pkg)
     }
 
-    /// Forwards to `Source::verify`
+    /// Forwards to `Source::verify`.
     fn verify(&self, pkg: PackageId) -> CargoResult<()> {
         (**self).verify(pkg)
     }
@@ -221,13 +229,13 @@ impl<'a, T: Source + ?Sized + 'a> Source for &'a mut T {
     }
 }
 
-/// A `HashMap` of `SourceId` -> `Box<Source>`
+/// A `HashMap` of `SourceId` -> `Box<Source>`.
 #[derive(Default)]
 pub struct SourceMap<'src> {
     map: HashMap<SourceId, Box<dyn Source + 'src>>,
 }
 
-// impl debug on source requires specialization, if even desirable at all
+// `impl Debug` on source requires specialization, if even desirable at all.
 impl<'src> fmt::Debug for SourceMap<'src> {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "SourceMap ")?;
@@ -236,19 +244,19 @@ impl<'src> fmt::Debug for SourceMap<'src> {
 }
 
 impl<'src> SourceMap<'src> {
-    /// Create an empty map
+    /// Creates an empty map.
     pub fn new() -> SourceMap<'src> {
         SourceMap {
             map: HashMap::new(),
         }
     }
 
-    /// Like `HashMap::contains_key`
+    /// Like `HashMap::contains_key`.
     pub fn contains(&self, id: SourceId) -> bool {
         self.map.contains_key(&id)
     }
 
-    /// Like `HashMap::get`
+    /// Like `HashMap::get`.
     pub fn get(&self, id: SourceId) -> Option<&(dyn Source + 'src)> {
         let source = self.map.get(&id);
 
@@ -258,7 +266,7 @@ impl<'src> SourceMap<'src> {
         })
     }
 
-    /// Like `HashMap::get_mut`
+    /// Like `HashMap::get_mut`.
     pub fn get_mut(&mut self, id: SourceId) -> Option<&mut (dyn Source + 'src)> {
         self.map.get_mut(&id).map(|s| {
             let s: &mut (dyn Source + 'src) = &mut **s;
@@ -266,34 +274,33 @@ impl<'src> SourceMap<'src> {
         })
     }
 
-    /// Like `HashMap::get`, but first calculates the `SourceId` from a
-    /// `PackageId`
+    /// Like `HashMap::get`, but first calculates the `SourceId` from a `PackageId`.
     pub fn get_by_package_id(&self, pkg_id: PackageId) -> Option<&(dyn Source + 'src)> {
         self.get(pkg_id.source_id())
     }
 
-    /// Like `HashMap::insert`, but derives the SourceId key from the Source
+    /// Like `HashMap::insert`, but derives the `SourceId` key from the `Source`.
     pub fn insert(&mut self, source: Box<dyn Source + 'src>) {
         let id = source.source_id();
         self.map.insert(id, source);
     }
 
-    /// Like `HashMap::is_empty`
+    /// Like `HashMap::is_empty`.
     pub fn is_empty(&self) -> bool {
         self.map.is_empty()
     }
 
-    /// Like `HashMap::len`
+    /// Like `HashMap::len`.
     pub fn len(&self) -> usize {
         self.map.len()
     }
 
-    /// Like `HashMap::values`
+    /// Like `HashMap::values`.
     pub fn sources<'a>(&'a self) -> impl Iterator<Item = &'a Box<dyn Source + 'src>> {
         self.map.values()
     }
 
-    /// Like `HashMap::iter_mut`
+    /// Like `HashMap::iter_mut`.
     pub fn sources_mut<'a>(
         &'a mut self,
     ) -> impl Iterator<Item = (&'a SourceId, &'a mut (dyn Source + 'src))> {
