@@ -4,16 +4,17 @@
 //! structure usable by Cargo itself. Currently this is primarily used to map
 //! sources to one another via the `replace-with` key in `.cargo/config`.
 
-use std::collections::HashMap;
+use std::collections::{HashMap, HashSet};
 use std::path::{Path, PathBuf};
 
+use log::debug;
 use url::Url;
 
-use core::{GitReference, Source, SourceId};
-use sources::{ReplacedSource, CRATES_IO_REGISTRY};
-use util::config::ConfigValue;
-use util::errors::{CargoResult, CargoResultExt};
-use util::{Config, ToUrl};
+use crate::core::{GitReference, PackageId, Source, SourceId};
+use crate::sources::{ReplacedSource, CRATES_IO_REGISTRY};
+use crate::util::config::ConfigValue;
+use crate::util::errors::{CargoResult, CargoResultExt};
+use crate::util::{Config, ToUrl};
 
 #[derive(Clone)]
 pub struct SourceConfigMap<'cfg> {
@@ -72,11 +73,15 @@ impl<'cfg> SourceConfigMap<'cfg> {
         self.config
     }
 
-    pub fn load(&self, id: SourceId) -> CargoResult<Box<Source + 'cfg>> {
+    pub fn load(
+        &self,
+        id: SourceId,
+        yanked_whitelist: &HashSet<PackageId>,
+    ) -> CargoResult<Box<dyn Source + 'cfg>> {
         debug!("loading: {}", id);
         let mut name = match self.id2name.get(&id) {
             Some(name) => name,
-            None => return Ok(id.load(self.config)?),
+            None => return Ok(id.load(self.config, yanked_whitelist)?),
         };
         let mut path = Path::new("/");
         let orig_name = name;
@@ -84,7 +89,7 @@ impl<'cfg> SourceConfigMap<'cfg> {
         loop {
             let cfg = match self.cfgs.get(name) {
                 Some(cfg) => cfg,
-                None => bail!(
+                None => failure::bail!(
                     "could not find a configured source with the \
                      name `{}` when attempting to lookup `{}` \
                      (configuration in `{}`)",
@@ -98,7 +103,7 @@ impl<'cfg> SourceConfigMap<'cfg> {
                     name = s;
                     path = p;
                 }
-                None if id == cfg.id => return Ok(id.load(self.config)?),
+                None if id == cfg.id => return Ok(id.load(self.config, yanked_whitelist)?),
                 None => {
                     new_id = cfg.id.with_precise(id.precise().map(|s| s.to_string()));
                     break;
@@ -106,7 +111,7 @@ impl<'cfg> SourceConfigMap<'cfg> {
             }
             debug!("following pointer to {}", name);
             if name == orig_name {
-                bail!(
+                failure::bail!(
                     "detected a cycle of `replace-with` sources, the source \
                      `{}` is eventually replaced with itself \
                      (configuration in `{}`)",
@@ -115,10 +120,17 @@ impl<'cfg> SourceConfigMap<'cfg> {
                 )
             }
         }
-        let new_src = new_id.load(self.config)?;
-        let old_src = id.load(self.config)?;
+
+        let new_src = new_id.load(
+            self.config,
+            &yanked_whitelist
+                .iter()
+                .map(|p| p.map_source(id, new_id))
+                .collect(),
+        )?;
+        let old_src = id.load(self.config, yanked_whitelist)?;
         if !new_src.supports_checksums() && old_src.supports_checksums() {
-            bail!(
+            failure::bail!(
                 "\
 cannot replace `{orig}` with `{name}`, the source `{orig}` supports \
 checksums, but `{name}` does not
@@ -131,7 +143,7 @@ a lock file compatible with `{orig}` cannot be generated in this situation
         }
 
         if old_src.requires_precise() && id.precise().is_none() {
-            bail!(
+            failure::bail!(
                 "\
 the source {orig} requires a lock file to be present first before it can be
 used against vendored source code
@@ -176,7 +188,7 @@ restore the source replacement configuration to continue the build
         }
         if let Some(val) = table.get("git") {
             let url = url(val, &format!("source.{}.git", name))?;
-            let try = |s: &str| {
+            let r#try = |s: &str| {
                 let val = match table.get(s) {
                     Some(s) => s,
                     None => return Ok(None),
@@ -184,11 +196,11 @@ restore the source replacement configuration to continue the build
                 let key = format!("source.{}.{}", name, s);
                 val.string(&key).map(Some)
             };
-            let reference = match try("branch")? {
+            let reference = match r#try("branch")? {
                 Some(b) => GitReference::Branch(b.0.to_string()),
-                None => match try("tag")? {
+                None => match r#try("tag")? {
                     Some(b) => GitReference::Tag(b.0.to_string()),
-                    None => match try("rev")? {
+                    None => match r#try("rev")? {
                         Some(b) => GitReference::Rev(b.0.to_string()),
                         None => GitReference::Branch("master".to_string()),
                     },
@@ -202,14 +214,14 @@ restore the source replacement configuration to continue the build
 
         let mut srcs = srcs.into_iter();
         let src = srcs.next().ok_or_else(|| {
-            format_err!(
+            failure::format_err!(
                 "no source URL specified for `source.{}`, need \
                  either `registry` or `local-registry` defined",
                 name
             )
         })?;
         if srcs.next().is_some() {
-            bail!("more than one source URL specified for `source.{}`", name)
+            failure::bail!("more than one source URL specified for `source.{}`", name)
         }
 
         let mut replace_with = None;
