@@ -1,7 +1,5 @@
-use cargo::util::process;
-use cargotest::{is_nightly, rustc_host};
-use cargotest::support::{basic_bin_manifest, cross_compile, execs, project};
-use hamcrest::{assert_that, existing_file};
+use crate::support::{basic_bin_manifest, basic_manifest, cross_compile, project};
+use crate::support::{is_nightly, rustc_host};
 
 #[test]
 fn simple_cross() {
@@ -9,7 +7,7 @@ fn simple_cross() {
         return;
     }
 
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -46,16 +44,10 @@ fn simple_cross() {
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        p.cargo("build").arg("--target").arg(&target).arg("-v"),
-        execs().with_status(0),
-    );
-    assert_that(&p.target_bin(&target, "foo"), existing_file());
+    p.cargo("build -v --target").arg(&target).run();
+    assert!(p.target_bin(&target, "foo").is_file());
 
-    assert_that(
-        process(&p.target_bin(&target, "foo")),
-        execs().with_status(0),
-    );
+    p.process(&p.target_bin(&target, "foo")).run();
 }
 
 #[test]
@@ -64,7 +56,7 @@ fn simple_cross_config() {
         return;
     }
 
-    let p = project("foo")
+    let p = project()
         .file(
             ".cargo/config",
             &format!(
@@ -111,13 +103,10 @@ fn simple_cross_config() {
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(p.cargo("build").arg("-v"), execs().with_status(0));
-    assert_that(&p.target_bin(&target, "foo"), existing_file());
+    p.cargo("build -v").run();
+    assert!(p.target_bin(&target, "foo").is_file());
 
-    assert_that(
-        process(&p.target_bin(&target, "foo")),
-        execs().with_status(0),
-    );
+    p.process(&p.target_bin(&target, "foo")).run();
 }
 
 #[test]
@@ -126,7 +115,7 @@ fn simple_deps() {
         return;
     }
 
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -139,38 +128,19 @@ fn simple_deps() {
             path = "../bar"
         "#,
         )
-        .file(
-            "src/main.rs",
-            r#"
-            extern crate bar;
-            fn main() { bar::bar(); }
-        "#,
-        )
+        .file("src/main.rs", "extern crate bar; fn main() { bar::bar(); }")
         .build();
-    let _p2 = project("bar")
-        .file(
-            "Cargo.toml",
-            r#"
-            [package]
-            name = "bar"
-            version = "0.0.1"
-            authors = []
-        "#,
-        )
+    let _p2 = project()
+        .at("bar")
+        .file("Cargo.toml", &basic_manifest("bar", "0.0.1"))
         .file("src/lib.rs", "pub fn bar() {}")
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        p.cargo("build").arg("--target").arg(&target),
-        execs().with_status(0),
-    );
-    assert_that(&p.target_bin(&target, "foo"), existing_file());
+    p.cargo("build --target").arg(&target).run();
+    assert!(p.target_bin(&target, "foo").is_file());
 
-    assert_that(
-        process(&p.target_bin(&target, "foo")),
-        execs().with_status(0),
-    );
+    p.process(&p.target_bin(&target, "foo")).run();
 }
 
 #[test]
@@ -182,7 +152,7 @@ fn plugin_deps() {
         return;
     }
 
-    let foo = project("foo")
+    let foo = project()
         .file(
             "Cargo.toml",
             r#"
@@ -210,7 +180,8 @@ fn plugin_deps() {
         "#,
         )
         .build();
-    let _bar = project("bar")
+    let _bar = project()
+        .at("bar")
         .file(
             "Cargo.toml",
             r#"
@@ -227,14 +198,14 @@ fn plugin_deps() {
         .file(
             "src/lib.rs",
             r#"
-            #![feature(plugin_registrar, quote, rustc_private)]
+            #![feature(plugin_registrar, rustc_private)]
 
             extern crate rustc_plugin;
             extern crate syntax;
 
             use rustc_plugin::Registry;
             use syntax::tokenstream::TokenTree;
-            use syntax::codemap::Span;
+            use syntax::source_map::Span;
             use syntax::ast::*;
             use syntax::ext::base::{ExtCtxt, MacEager, MacResult};
             use syntax::ext::build::AstBuilder;
@@ -251,30 +222,17 @@ fn plugin_deps() {
         "#,
         )
         .build();
-    let _baz = project("baz")
-        .file(
-            "Cargo.toml",
-            r#"
-            [package]
-            name = "baz"
-            version = "0.0.1"
-            authors = []
-        "#,
-        )
+    let _baz = project()
+        .at("baz")
+        .file("Cargo.toml", &basic_manifest("baz", "0.0.1"))
         .file("src/lib.rs", "pub fn baz() -> i32 { 1 }")
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        foo.cargo("build").arg("--target").arg(&target),
-        execs().with_status(0),
-    );
-    assert_that(&foo.target_bin(&target, "foo"), existing_file());
+    foo.cargo("build --target").arg(&target).run();
+    assert!(foo.target_bin(&target, "foo").is_file());
 
-    assert_that(
-        process(&foo.target_bin(&target, "foo")),
-        execs().with_status(0),
-    );
+    foo.process(&foo.target_bin(&target, "foo")).run();
 }
 
 #[test]
@@ -286,7 +244,7 @@ fn plugin_to_the_max() {
         return;
     }
 
-    let foo = project("foo")
+    let foo = project()
         .file(
             "Cargo.toml",
             r#"
@@ -314,7 +272,8 @@ fn plugin_to_the_max() {
         "#,
         )
         .build();
-    let _bar = project("bar")
+    let _bar = project()
+        .at("bar")
         .file(
             "Cargo.toml",
             r#"
@@ -334,7 +293,7 @@ fn plugin_to_the_max() {
         .file(
             "src/lib.rs",
             r#"
-            #![feature(plugin_registrar, quote, rustc_private)]
+            #![feature(plugin_registrar, rustc_private)]
 
             extern crate rustc_plugin;
             extern crate syntax;
@@ -342,7 +301,7 @@ fn plugin_to_the_max() {
 
             use rustc_plugin::Registry;
             use syntax::tokenstream::TokenTree;
-            use syntax::codemap::Span;
+            use syntax::source_map::Span;
             use syntax::ast::*;
             use syntax::ext::base::{ExtCtxt, MacEager, MacResult};
             use syntax::ext::build::AstBuilder;
@@ -362,35 +321,19 @@ fn plugin_to_the_max() {
         "#,
         )
         .build();
-    let _baz = project("baz")
-        .file(
-            "Cargo.toml",
-            r#"
-            [package]
-            name = "baz"
-            version = "0.0.1"
-            authors = []
-        "#,
-        )
+    let _baz = project()
+        .at("baz")
+        .file("Cargo.toml", &basic_manifest("baz", "0.0.1"))
         .file("src/lib.rs", "pub fn baz() -> i32 { 1 }")
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        foo.cargo("build").arg("--target").arg(&target).arg("-v"),
-        execs().with_status(0),
-    );
+    foo.cargo("build -v --target").arg(&target).run();
     println!("second");
-    assert_that(
-        foo.cargo("build").arg("-v").arg("--target").arg(&target),
-        execs().with_status(0),
-    );
-    assert_that(&foo.target_bin(&target, "foo"), existing_file());
+    foo.cargo("build -v --target").arg(&target).run();
+    assert!(foo.target_bin(&target, "foo").is_file());
 
-    assert_that(
-        process(&foo.target_bin(&target, "foo")),
-        execs().with_status(0),
-    );
+    foo.process(&foo.target_bin(&target, "foo")).run();
 }
 
 #[test]
@@ -400,7 +343,7 @@ fn linker_and_ar() {
     }
 
     let target = cross_compile::alternate();
-    let p = project("foo")
+    let p = project()
         .file(
             ".cargo/config",
             &format!(
@@ -427,25 +370,24 @@ fn linker_and_ar() {
         )
         .build();
 
-    assert_that(
-        p.cargo("build").arg("--target").arg(&target).arg("-v"),
-        execs().with_status(101).with_stderr_contains(&format!(
+    p.cargo("build -v --target")
+        .arg(&target)
+        .with_status(101)
+        .with_stderr_contains(&format!(
             "\
-[COMPILING] foo v0.5.0 ({url})
-[RUNNING] `rustc --crate-name foo src[/]foo.rs --crate-type bin \
+[COMPILING] foo v0.5.0 ([CWD])
+[RUNNING] `rustc --crate-name foo src/foo.rs --color never --crate-type bin \
     --emit=dep-info,link -C debuginfo=2 \
     -C metadata=[..] \
-    --out-dir {dir}[/]target[/]{target}[/]debug[/]deps \
+    --out-dir [CWD]/target/{target}/debug/deps \
     --target {target} \
     -C ar=my-ar-tool -C linker=my-linker-tool \
-    -L dependency={dir}[/]target[/]{target}[/]debug[/]deps \
-    -L dependency={dir}[/]target[/]debug[/]deps`
+    -L dependency=[CWD]/target/{target}/debug/deps \
+    -L dependency=[CWD]/target/debug/deps`
 ",
-            dir = p.root().display(),
-            url = p.url(),
             target = target,
-        )),
-    );
+        ))
+        .run();
 }
 
 #[test]
@@ -457,7 +399,7 @@ fn plugin_with_extra_dylib_dep() {
         return;
     }
 
-    let foo = project("foo")
+    let foo = project()
         .file(
             "Cargo.toml",
             r#"
@@ -480,7 +422,8 @@ fn plugin_with_extra_dylib_dep() {
         "#,
         )
         .build();
-    let _bar = project("bar")
+    let _bar = project()
+        .at("bar")
         .file(
             "Cargo.toml",
             r#"
@@ -514,7 +457,8 @@ fn plugin_with_extra_dylib_dep() {
         "#,
         )
         .build();
-    let _baz = project("baz")
+    let _baz = project()
+        .at("baz")
         .file(
             "Cargo.toml",
             r#"
@@ -532,10 +476,7 @@ fn plugin_with_extra_dylib_dep() {
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        foo.cargo("build").arg("--target").arg(&target),
-        execs().with_status(0),
-    );
+    foo.cargo("build --target").arg(&target).run();
 }
 
 #[test]
@@ -544,7 +485,7 @@ fn cross_tests() {
         return;
     }
 
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -586,22 +527,19 @@ fn cross_tests() {
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        p.cargo("test").arg("--target").arg(&target),
-        execs()
-            .with_status(0)
-            .with_stderr(&format!(
-                "\
-[COMPILING] foo v0.0.0 ({foo})
+    p.cargo("test --target")
+        .arg(&target)
+        .with_stderr(&format!(
+            "\
+[COMPILING] foo v0.0.0 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
-[RUNNING] target[/]{triple}[/]debug[/]deps[/]foo-[..][EXE]
-[RUNNING] target[/]{triple}[/]debug[/]deps[/]bar-[..][EXE]",
-                foo = p.url(),
-                triple = target
-            ))
-            .with_stdout_contains("test test_foo ... ok")
-            .with_stdout_contains("test test ... ok"),
-    );
+[RUNNING] target/{triple}/debug/deps/foo-[..][EXE]
+[RUNNING] target/{triple}/debug/deps/bar-[..][EXE]",
+            triple = target
+        ))
+        .with_stdout_contains("test test_foo ... ok")
+        .with_stdout_contains("test test ... ok")
+        .run();
 }
 
 #[test]
@@ -610,16 +548,7 @@ fn no_cross_doctests() {
         return;
     }
 
-    let p = project("foo")
-        .file(
-            "Cargo.toml",
-            r#"
-            [project]
-            name = "foo"
-            authors = []
-            version = "0.0.0"
-        "#,
-        )
+    let p = project()
         .file(
             "src/lib.rs",
             r#"
@@ -631,52 +560,44 @@ fn no_cross_doctests() {
         )
         .build();
 
-    let host_output = format!(
-        "\
-[COMPILING] foo v0.0.0 ({foo})
+    let host_output = "\
+[COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
-[RUNNING] target[/]debug[/]deps[/]foo-[..][EXE]
+[RUNNING] target/debug/deps/foo-[..][EXE]
 [DOCTEST] foo
-",
-        foo = p.url()
-    );
+";
 
     println!("a");
-    assert_that(
-        p.cargo("test"),
-        execs().with_status(0).with_stderr(&host_output),
-    );
+    p.cargo("test").with_stderr(&host_output).run();
 
     println!("b");
     let target = cross_compile::host();
-    assert_that(
-        p.cargo("test").arg("--target").arg(&target),
-        execs().with_status(0).with_stderr(&format!(
+    p.cargo("test --target")
+        .arg(&target)
+        .with_stderr(&format!(
             "\
-[COMPILING] foo v0.0.0 ({foo})
+[COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
-[RUNNING] target[/]{triple}[/]debug[/]deps[/]foo-[..][EXE]
+[RUNNING] target/{triple}/debug/deps/foo-[..][EXE]
 [DOCTEST] foo
 ",
-            foo = p.url(),
             triple = target
-        )),
-    );
+        ))
+        .run();
 
     println!("c");
     let target = cross_compile::alternate();
-    assert_that(
-        p.cargo("test").arg("--target").arg(&target),
-        execs().with_status(0).with_stderr(&format!(
+    p.cargo("test --target")
+        .arg(&target)
+        .with_stderr(&format!(
             "\
-[COMPILING] foo v0.0.0 ({foo})
+[COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
-[RUNNING] target[/]{triple}[/]debug[/]deps[/]foo-[..][EXE]
+[RUNNING] target/{triple}/debug/deps/foo-[..][EXE]
 ",
-            foo = p.url(),
             triple = target
-        )),
-    );
+        ))
+        .run();
 }
 
 #[test]
@@ -685,16 +606,7 @@ fn simple_cargo_run() {
         return;
     }
 
-    let p = project("foo")
-        .file(
-            "Cargo.toml",
-            r#"
-            [package]
-            name = "foo"
-            version = "0.0.0"
-            authors = []
-        "#,
-        )
+    let p = project()
         .file(
             "src/main.rs",
             &format!(
@@ -710,10 +622,7 @@ fn simple_cargo_run() {
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        p.cargo("run").arg("--target").arg(&target),
-        execs().with_status(0),
-    );
+    p.cargo("run --target").arg(&target).run();
 }
 
 #[test]
@@ -723,7 +632,7 @@ fn cross_with_a_build_script() {
     }
 
     let target = cross_compile::alternate();
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -763,20 +672,19 @@ fn cross_with_a_build_script() {
         .file("src/main.rs", "fn main() {}")
         .build();
 
-    assert_that(
-        p.cargo("build").arg("--target").arg(&target).arg("-v"),
-        execs().with_status(0).with_stderr(&format!(
+    p.cargo("build -v --target")
+        .arg(&target)
+        .with_stderr(&format!(
             "\
-[COMPILING] foo v0.0.0 (file://[..])
-[RUNNING] `rustc [..] build.rs [..] --out-dir {dir}[/]target[/]debug[/]build[/]foo-[..]`
-[RUNNING] `{dir}[/]target[/]debug[/]build[/]foo-[..][/]build-script-build`
-[RUNNING] `rustc [..] src[/]main.rs [..] --target {target} [..]`
+[COMPILING] foo v0.0.0 ([CWD])
+[RUNNING] `rustc [..] build.rs [..] --out-dir [CWD]/target/debug/build/foo-[..]`
+[RUNNING] `[CWD]/target/debug/build/foo-[..]/build-script-build`
+[RUNNING] `rustc [..] src/main.rs [..] --target {target} [..]`
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 ",
             target = target,
-            dir = p.root().display()
-        )),
-    );
+        ))
+        .run();
 }
 
 #[test]
@@ -787,7 +695,7 @@ fn build_script_needed_for_host_and_target() {
 
     let target = cross_compile::alternate();
     let host = rustc_host();
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -829,12 +737,7 @@ fn build_script_needed_for_host_and_target() {
             build = 'build.rs'
         "#,
         )
-        .file(
-            "d1/src/lib.rs",
-            "
-            pub fn d1() {}
-        ",
-        )
+        .file("d1/src/lib.rs", "pub fn d1() {}")
         .file(
             "d1/build.rs",
             r#"
@@ -867,47 +770,32 @@ fn build_script_needed_for_host_and_target() {
         )
         .build();
 
-    assert_that(
-        p.cargo("build").arg("--target").arg(&target).arg("-v"),
-        execs()
-            .with_status(0)
-            .with_stderr_contains(&format!(
-                "[COMPILING] d1 v0.0.0 ({url}/d1)",
-                url = p.url()
-            ))
-            .with_stderr_contains(&format!("[RUNNING] `rustc [..] d1[/]build.rs [..] --out-dir {dir}[/]target[/]debug[/]build[/]d1-[..]`",
-    dir = p.root().display()))
-            .with_stderr_contains(&format!(
-                "[RUNNING] `{dir}[/]target[/]debug[/]build[/]d1-[..][/]build-script-build`",
-                dir = p.root().display()
-            ))
-            .with_stderr_contains(
-                "[RUNNING] `rustc [..] d1[/]src[/]lib.rs [..]`",
-            )
-            .with_stderr_contains(&format!(
-                "[COMPILING] d2 v0.0.0 ({url}/d2)",
-                url = p.url()
-            ))
-            .with_stderr_contains(&format!(
-                "\
-                 [RUNNING] `rustc [..] d2[/]src[/]lib.rs [..] \
-                 -L /path/to/{host}`",
-                host = host
-            ))
-            .with_stderr_contains(&format!(
-                "[COMPILING] foo v0.0.0 ({url})",
-                url = p.url()
-            ))
-            .with_stderr_contains(&format!("\
-[RUNNING] `rustc [..] build.rs [..] --out-dir {dir}[/]target[/]debug[/]build[/]foo-[..] \
-           -L /path/to/{host}`", dir = p.root().display(), host = host))
-            .with_stderr_contains(&format!(
-                "\
-                 [RUNNING] `rustc [..] src[/]main.rs [..] --target {target} [..] \
-                 -L /path/to/{target}`",
-                target = target
-            )),
-    );
+    p.cargo("build -v --target")
+        .arg(&target)
+        .with_stderr_contains(&"[COMPILING] d1 v0.0.0 ([CWD]/d1)")
+        .with_stderr_contains(
+            "[RUNNING] `rustc [..] d1/build.rs [..] --out-dir [CWD]/target/debug/build/d1-[..]`",
+        )
+        .with_stderr_contains("[RUNNING] `[CWD]/target/debug/build/d1-[..]/build-script-build`")
+        .with_stderr_contains("[RUNNING] `rustc [..] d1/src/lib.rs [..]`")
+        .with_stderr_contains("[COMPILING] d2 v0.0.0 ([CWD]/d2)")
+        .with_stderr_contains(&format!(
+            "[RUNNING] `rustc [..] d2/src/lib.rs [..] -L /path/to/{host}`",
+            host = host
+        ))
+        .with_stderr_contains("[COMPILING] foo v0.0.0 ([CWD])")
+        .with_stderr_contains(&format!(
+            "[RUNNING] `rustc [..] build.rs [..] --out-dir [CWD]/target/debug/build/foo-[..] \
+             -L /path/to/{host}`",
+            host = host
+        ))
+        .with_stderr_contains(&format!(
+            "\
+             [RUNNING] `rustc [..] src/main.rs [..] --target {target} [..] \
+             -L /path/to/{target}`",
+            target = target
+        ))
+        .run();
 }
 
 #[test]
@@ -916,7 +804,7 @@ fn build_deps_for_the_right_arch() {
         return;
     }
 
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -930,21 +818,8 @@ fn build_deps_for_the_right_arch() {
         "#,
         )
         .file("src/main.rs", "extern crate d2; fn main() {}")
-        .file(
-            "d1/Cargo.toml",
-            r#"
-            [package]
-            name = "d1"
-            version = "0.0.0"
-            authors = []
-        "#,
-        )
-        .file(
-            "d1/src/lib.rs",
-            "
-            pub fn d1() {}
-        ",
-        )
+        .file("d1/Cargo.toml", &basic_manifest("d1", "0.0.0"))
+        .file("d1/src/lib.rs", "pub fn d1() {}")
         .file(
             "d2/Cargo.toml",
             r#"
@@ -963,10 +838,7 @@ fn build_deps_for_the_right_arch() {
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        p.cargo("build").arg("--target").arg(&target).arg("-v"),
-        execs().with_status(0),
-    );
+    p.cargo("build -v --target").arg(&target).run();
 }
 
 #[test]
@@ -975,7 +847,7 @@ fn build_script_only_host() {
         return;
     }
 
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -1001,12 +873,7 @@ fn build_script_only_host() {
             build = "build.rs"
         "#,
         )
-        .file(
-            "d1/src/lib.rs",
-            "
-            pub fn d1() {}
-        ",
-        )
+        .file("d1/src/lib.rs", "pub fn d1() {}")
         .file(
             "d1/build.rs",
             r#"
@@ -1022,10 +889,7 @@ fn build_script_only_host() {
         .build();
 
     let target = cross_compile::alternate();
-    assert_that(
-        p.cargo("build").arg("--target").arg(&target).arg("-v"),
-        execs().with_status(0),
-    );
+    p.cargo("build -v --target").arg(&target).run();
 }
 
 #[test]
@@ -1033,7 +897,7 @@ fn plugin_build_script_right_arch() {
     if cross_compile::disabled() {
         return;
     }
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -1052,21 +916,18 @@ fn plugin_build_script_right_arch() {
         .file("src/lib.rs", "")
         .build();
 
-    assert_that(
-        p.cargo("build")
-            .arg("-v")
-            .arg("--target")
-            .arg(cross_compile::alternate()),
-        execs().with_status(0).with_stderr(
+    p.cargo("build -v --target")
+        .arg(cross_compile::alternate())
+        .with_stderr(
             "\
 [COMPILING] foo v0.0.1 ([..])
 [RUNNING] `rustc [..] build.rs [..]`
-[RUNNING] `[..][/]build-script-build`
-[RUNNING] `rustc [..] src[/]lib.rs [..]`
+[RUNNING] `[..]/build-script-build`
+[RUNNING] `rustc [..] src/lib.rs [..]`
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 ",
-        ),
-    );
+        )
+        .run();
 }
 
 #[test]
@@ -1077,7 +938,7 @@ fn build_script_with_platform_specific_dependencies() {
 
     let target = cross_compile::alternate();
     let host = rustc_host();
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -1117,41 +978,29 @@ fn build_script_with_platform_specific_dependencies() {
         )
         .file(
             "d1/src/lib.rs",
-            "
-            #[allow(unused_extern_crates)]
-            extern crate d2;
-        ",
-        )
-        .file(
-            "d2/Cargo.toml",
-            r#"
-            [package]
-            name = "d2"
-            version = "0.0.0"
-            authors = []
-        "#,
+            "#[allow(unused_extern_crates)] extern crate d2;",
         )
+        .file("d2/Cargo.toml", &basic_manifest("d2", "0.0.0"))
         .file("d2/src/lib.rs", "")
         .build();
 
-    assert_that(
-        p.cargo("build").arg("-v").arg("--target").arg(&target),
-        execs().with_status(0).with_stderr(&format!(
+    p.cargo("build -v --target")
+        .arg(&target)
+        .with_stderr(&format!(
             "\
 [COMPILING] d2 v0.0.0 ([..])
-[RUNNING] `rustc [..] d2[/]src[/]lib.rs [..]`
+[RUNNING] `rustc [..] d2/src/lib.rs [..]`
 [COMPILING] d1 v0.0.0 ([..])
-[RUNNING] `rustc [..] d1[/]src[/]lib.rs [..]`
+[RUNNING] `rustc [..] d1/src/lib.rs [..]`
 [COMPILING] foo v0.0.1 ([..])
 [RUNNING] `rustc [..] build.rs [..]`
-[RUNNING] `{dir}[/]target[/]debug[/]build[/]foo-[..][/]build-script-build`
-[RUNNING] `rustc [..] src[/]lib.rs [..] --target {target} [..]`
+[RUNNING] `[CWD]/target/debug/build/foo-[..]/build-script-build`
+[RUNNING] `rustc [..] src/lib.rs [..] --target {target} [..]`
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 ",
-            dir = p.root().display(),
             target = target
-        )),
-    );
+        ))
+        .run();
 }
 
 #[test]
@@ -1162,7 +1011,7 @@ fn platform_specific_dependencies_do_not_leak() {
 
     let target = cross_compile::alternate();
     let host = rustc_host();
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -1197,24 +1046,15 @@ fn platform_specific_dependencies_do_not_leak() {
             ),
         )
         .file("d1/src/lib.rs", "extern crate d2;")
-        .file(
-            "d2/Cargo.toml",
-            r#"
-            [package]
-            name = "d2"
-            version = "0.0.0"
-            authors = []
-        "#,
-        )
+        .file("d1/Cargo.toml", &basic_manifest("d1", "0.0.0"))
         .file("d2/src/lib.rs", "")
         .build();
 
-    assert_that(
-        p.cargo("build").arg("-v").arg("--target").arg(&target),
-        execs()
-            .with_status(101)
-            .with_stderr_contains("[..] can't find crate for `d2`[..]"),
-    );
+    p.cargo("build -v --target")
+        .arg(&target)
+        .with_status(101)
+        .with_stderr_contains("[..] can't find crate for `d2`[..]")
+        .run();
 }
 
 #[test]
@@ -1225,7 +1065,7 @@ fn platform_specific_variables_reflected_in_build_scripts() {
 
     let target = cross_compile::alternate();
     let host = rustc_host();
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             &format!(
@@ -1282,12 +1122,7 @@ fn platform_specific_variables_reflected_in_build_scripts() {
             build = "build.rs"
         "#,
         )
-        .file(
-            "d1/build.rs",
-            r#"
-            fn main() { println!("cargo:val=1") }
-        "#,
-        )
+        .file("d1/build.rs", r#"fn main() { println!("cargo:val=1") }"#)
         .file("d1/src/lib.rs", "")
         .file(
             "d2/Cargo.toml",
@@ -1300,20 +1135,12 @@ fn platform_specific_variables_reflected_in_build_scripts() {
             build = "build.rs"
         "#,
         )
-        .file(
-            "d2/build.rs",
-            r#"
-            fn main() { println!("cargo:val=1") }
-        "#,
-        )
+        .file("d2/build.rs", r#"fn main() { println!("cargo:val=1") }"#)
         .file("d2/src/lib.rs", "")
         .build();
 
-    assert_that(p.cargo("build").arg("-v"), execs().with_status(0));
-    assert_that(
-        p.cargo("build").arg("-v").arg("--target").arg(&target),
-        execs().with_status(0),
-    );
+    p.cargo("build -v").run();
+    p.cargo("build -v --target").arg(&target).run();
 }
 
 #[test]
@@ -1324,7 +1151,7 @@ fn cross_test_dylib() {
 
     let target = cross_compile::alternate();
 
-    let p = project("foo")
+    let p = project()
         .file(
             "Cargo.toml",
             r#"
@@ -1388,20 +1215,17 @@ fn cross_test_dylib() {
         )
         .build();
 
-    assert_that(
-        p.cargo("test").arg("--target").arg(&target),
-        execs()
-            .with_status(0)
-            .with_stderr(&format!(
-                "\
-[COMPILING] bar v0.0.1 ({dir}/bar)
-[COMPILING] foo v0.0.1 ({dir})
+    p.cargo("test --target")
+        .arg(&target)
+        .with_stderr(&format!(
+            "\
+[COMPILING] bar v0.0.1 ([CWD]/bar)
+[COMPILING] foo v0.0.1 ([CWD])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
-[RUNNING] target[/]{arch}[/]debug[/]deps[/]foo-[..][EXE]
-[RUNNING] target[/]{arch}[/]debug[/]deps[/]test-[..][EXE]",
-                dir = p.url(),
-                arch = cross_compile::alternate()
-            ))
-            .with_stdout_contains_n("test foo ... ok", 2),
-    );
+[RUNNING] target/{arch}/debug/deps/foo-[..][EXE]
+[RUNNING] target/{arch}/debug/deps/test-[..][EXE]",
+            arch = cross_compile::alternate()
+        ))
+        .with_stdout_contains_n("test foo ... ok", 2)
+        .run();
 }
