@@ -3,9 +3,8 @@ use std::io::{self, Read};
 use std::net::TcpListener;
 use std::process::{Child, Stdio};
 use std::thread;
-use std::time::Duration;
 
-use crate::support::project;
+use crate::{support::project, support::slow_cpu_multiplier};
 
 #[cfg(unix)]
 fn enabled() -> bool {
@@ -121,7 +120,7 @@ fn ctrl_c_kills_everyone() {
             Ok(()) => return,
             Err(e) => println!("attempt {}: {}", i, e),
         }
-        thread::sleep(Duration::from_millis(100));
+        thread::sleep(slow_cpu_multiplier(100));
     }
 
     panic!(
@@ -132,8 +131,6 @@ fn ctrl_c_kills_everyone() {
 
 #[cfg(unix)]
 fn ctrl_c(child: &mut Child) {
-    use libc;
-
     let r = unsafe { libc::kill(-(child.id() as i32), libc::SIGINT) };
     if r < 0 {
         panic!("failed to kill: {}", io::Error::last_os_error());
