@@ -943,7 +943,6 @@ fn fix_idioms() {
 ";
     p.cargo("fix --edition-idioms --allow-no-vcs")
         .with_stderr(stderr)
-        .with_status(0)
         .run();
 
     assert!(p.read_file("src/lib.rs").contains("Box<dyn Any>"));
@@ -955,7 +954,6 @@ fn idioms_2015_ok() {
 
     p.cargo("fix --edition-idioms --allow-no-vcs")
         .masquerade_as_nightly_cargo()
-        .with_status(0)
         .run();
 }
 
@@ -1276,8 +1274,14 @@ fn fix_to_broken_code() {
 fn fix_with_common() {
     let p = project()
         .file("src/lib.rs", "")
-        .file("tests/t1.rs", "mod common; #[test] fn t1() { common::try(); }")
-        .file("tests/t2.rs", "mod common; #[test] fn t2() { common::try(); }")
+        .file(
+            "tests/t1.rs",
+            "mod common; #[test] fn t1() { common::try(); }",
+        )
+        .file(
+            "tests/t2.rs",
+            "mod common; #[test] fn t2() { common::try(); }",
+        )
         .file("tests/common/mod.rs", "pub fn try() {}")
         .build();
 
