@@ -70,7 +70,7 @@ fn metadata_warning() {
             "\
 warning: manifest has no description, license, license-file, documentation, \
 homepage or repository.
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [PACKAGING] foo v0.0.1 ([CWD])
 [VERIFYING] foo v0.0.1 ([CWD])
 [COMPILING] foo v0.0.1 ([CWD][..])
@@ -96,7 +96,7 @@ See http://doc.crates.io/manifest.html#package-metadata for more info.
         .with_stderr(
             "\
 warning: manifest has no description, documentation, homepage or repository.
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [PACKAGING] foo v0.0.1 ([CWD])
 [VERIFYING] foo v0.0.1 ([CWD])
 [COMPILING] foo v0.0.1 ([CWD][..])
@@ -149,7 +149,7 @@ fn package_verbose() {
         .with_stderr(
             "\
 [WARNING] manifest has no description[..]
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [PACKAGING] foo v0.0.1 ([..])
 [ARCHIVING] [..]
 [ARCHIVING] [..]
@@ -186,7 +186,7 @@ See http://doc.crates.io/manifest.html#package-metadata for more info.
         .with_stderr(
             "\
 [WARNING] manifest has no description[..]
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [PACKAGING] a v0.0.1 ([..])
 [ARCHIVING] Cargo.toml
 [ARCHIVING] src/lib.rs
@@ -204,7 +204,7 @@ fn package_verification() {
         .with_stderr(
             "\
 [WARNING] manifest has no description[..]
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [PACKAGING] foo v0.0.1 ([CWD])
 [VERIFYING] foo v0.0.1 ([CWD])
 [COMPILING] foo v0.0.1 ([CWD][..])
@@ -280,7 +280,7 @@ fn path_dependency_no_version() {
         .with_stderr(
             "\
 [WARNING] manifest has no documentation, homepage or repository.
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [ERROR] all path dependencies must have a version specified when packaging.
 dependency `bar` does not specify a version.
 ",
@@ -331,25 +331,25 @@ fn exclude() {
         .file("src/main.rs", r#"fn main() { println!("hello"); }"#)
         .file("bar.txt", "")
         .file("src/bar.txt", "")
-        // file in root
+        // File in root.
         .file("file_root_1", "")
         .file("file_root_2", "")
         .file("file_root_3", "")
         .file("file_root_4", "")
         .file("file_root_5", "")
-        // file in sub-dir
+        // File in sub-dir.
         .file("some_dir/file_deep_1", "")
         .file("some_dir/file_deep_2", "")
         .file("some_dir/file_deep_3", "")
         .file("some_dir/file_deep_4", "")
         .file("some_dir/file_deep_5", "")
-        // dir in root
+        // Dir in root.
         .file("dir_root_1/some_dir/file", "")
         .file("dir_root_2/some_dir/file", "")
         .file("dir_root_3/some_dir/file", "")
         .file("dir_root_4/some_dir/file", "")
         .file("dir_root_5/some_dir/file", "")
-        // dir in sub-dir
+        // Dir in sub-dir.
         .file("some_dir/dir_deep_1/some_dir/file", "")
         .file("some_dir/dir_deep_2/some_dir/file", "")
         .file("some_dir/dir_deep_3/some_dir/file", "")
@@ -363,7 +363,7 @@ fn exclude() {
         .with_stderr(
             "\
 [WARNING] manifest has no description[..]
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [WARNING] [..] file `dir_root_1/some_dir/file` WILL be excluded [..]
 See [..]
 [WARNING] [..] file `dir_root_2/some_dir/file` WILL be excluded [..]
@@ -447,7 +447,8 @@ fn include() {
         )
         .file("foo.txt", "")
         .file("src/main.rs", r#"fn main() { println!("hello"); }"#)
-        .file("src/bar.txt", "") // should be ignored when packaging
+        // Should be ignored when packaging.
+        .file("src/bar.txt", "")
         .build();
 
     cargo_process("package --no-verify -v")
@@ -455,7 +456,7 @@ fn include() {
         .with_stderr(
             "\
 [WARNING] manifest has no description[..]
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [PACKAGING] foo v0.0.1 ([..])
 [ARCHIVING] [..]
 [ARCHIVING] [..]
@@ -569,7 +570,7 @@ fn ignore_nested() {
         .with_stderr(
             "\
 [WARNING] manifest has no documentation[..]
-See http://doc.crates.io/manifest.html#package-metadata for more info.
+See <http://doc.crates.io/manifest.html#package-metadata> for more info.
 [PACKAGING] foo v0.0.1 ([CWD])
 [VERIFYING] foo v0.0.1 ([CWD])
 [COMPILING] foo v0.0.1 ([CWD][..])
@@ -597,7 +598,8 @@ src[..]main.rs
     );
 }
 
-#[cfg(unix)] // windows doesn't allow these characters in filenames
+// Windows doesn't allow these characters in filenames.
+#[cfg(unix)]
 #[test]
 fn package_weird_characters() {
     let p = project()
@@ -807,7 +809,7 @@ fn generated_manifest() {
 # When uploading crates to the registry Cargo will automatically
 # "normalize" Cargo.toml files for maximal compatibility
 # with all versions of Cargo and also rewrite `path` dependencies
-# to registry (e.g. crates.io) dependencies
+# to registry (e.g., crates.io) dependencies
 #
 # If you believe there's an error in this file please file an
 # issue against the rust-lang/cargo repository. If you're
@@ -892,7 +894,7 @@ fn ignore_workspace_specifier() {
 # When uploading crates to the registry Cargo will automatically
 # "normalize" Cargo.toml files for maximal compatibility
 # with all versions of Cargo and also rewrite `path` dependencies
-# to registry (e.g. crates.io) dependencies
+# to registry (e.g., crates.io) dependencies
 #
 # If you believe there's an error in this file please file an
 # issue against the rust-lang/cargo repository. If you're
@@ -1254,17 +1256,16 @@ fn package_with_select_features() {
             required = []
             optional = []
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "#[cfg(not(feature = \"required\"))]
              compile_error!(\"This crate requires `required` feature!\");
              fn main() {}",
-        ).build();
+        )
+        .build();
 
-    p.cargo("package --features required")
-        .masquerade_as_nightly_cargo()
-        .with_status(0)
-        .run();
+    p.cargo("package --features required").masquerade_as_nightly_cargo().run();
 }
 
 #[test]
@@ -1284,17 +1285,16 @@ fn package_with_all_features() {
             required = []
             optional = []
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "#[cfg(not(feature = \"required\"))]
              compile_error!(\"This crate requires `required` feature!\");
              fn main() {}",
-        ).build();
+        )
+        .build();
 
-    p.cargo("package --all-features")
-        .masquerade_as_nightly_cargo()
-        .with_status(0)
-        .run();
+    p.cargo("package --all-features").masquerade_as_nightly_cargo().run();
 }
 
 #[test]
@@ -1314,12 +1314,14 @@ fn package_no_default_features() {
             default = ["required"]
             required = []
         "#,
-        ).file(
+        )
+        .file(
             "src/main.rs",
             "#[cfg(not(feature = \"required\"))]
              compile_error!(\"This crate requires `required` feature!\");
              fn main() {}",
-        ).build();
+        )
+        .build();
 
     p.cargo("package --no-default-features")
         .masquerade_as_nightly_cargo()
