@@ -7,8 +7,9 @@ use crate::support::sleep_ms;
 use crate::support::{basic_lib_manifest, basic_manifest, main_file, project};
 
 #[test]
-#[cfg(not(windows))] // I have no idea why this is failing spuriously on
-                     // Windows, for more info see #3466.
+// I have no idea why this is failing spuriously on Windows;
+// for more info, see #3466.
+#[cfg(not(windows))]
 fn cargo_compile_with_nested_deps_shorthand() {
     let p = project()
         .file(
@@ -981,7 +982,7 @@ fn invalid_path_dep_in_workspace_with_lockfile() {
             "\
 error: no matching package named `bar` found
 location searched: [..]
-did you mean: foo
+perhaps you meant: foo
 required by package `foo v0.5.0 ([..])`
 ",
         )
