@@ -1,4 +1,4 @@
-use support::project;
+use crate::support::project;
 
 #[test]
 fn parses_env() {
@@ -20,7 +20,8 @@ fn parses_config() {
             [build]
             rustdocflags = ["--cfg", "foo"]
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("doc -v")
         .with_stderr_contains("[RUNNING] `rustdoc [..] --cfg foo[..]`")
@@ -34,6 +35,7 @@ fn bad_flags() {
     p.cargo("doc")
         .env("RUSTDOCFLAGS", "--bogus")
         .with_status(101)
+        .with_stderr_contains("[..]bogus[..]")
         .run();
 }
 
@@ -53,7 +55,8 @@ fn rerun() {
 [DOCUMENTING] foo v0.0.1 ([..])
 [FINISHED] dev [unoptimized + debuginfo] target(s) in [..]
 ",
-        ).run();
+        )
+        .run();
 }
 
 #[test]
@@ -66,7 +69,8 @@ fn rustdocflags_passed_to_rustdoc_through_cargo_test() {
             //! assert!(cfg!(do_not_choke));
             //! ```
         "#,
-        ).build();
+        )
+        .build();
 
     p.cargo("test --doc")
         .env("RUSTDOCFLAGS", "--cfg do_not_choke")
