@@ -1,4 +1,4 @@
-use support::{basic_bin_manifest, main_file, project};
+use crate::support::{basic_bin_manifest, main_file, project};
 
 fn verify_project_success_output() -> String {
     r#"{"success":"true"}"#.into()
@@ -46,13 +46,16 @@ fn cargo_verify_project_cwd() {
 #[test]
 fn cargo_verify_project_honours_unstable_features() {
     let p = project()
-        .file("Cargo.toml", r#"
+        .file(
+            "Cargo.toml",
+            r#"
         cargo-features = ["test-dummy-unstable"]
 
         [package]
         name = "foo"
         version = "0.0.1"
-    "#)
+    "#,
+        )
         .file("src/lib.rs", "")
         .build();
 
